@@ -1,4 +1,4 @@
-#' Calculate the gamma statistic, using a fast implementation in C++.
+#' Gamma statistic
 #' @description The gamma statistic measures the relative position of
 #' internal nodes within a reconstructed phylogeny. Under the Yule process,
 #' the gamma values of a reconstructed tree follow a standard normal
@@ -19,6 +19,10 @@
 #' }
 gamma_statistic <- function(phy) {
 
+  check_tree(phy,
+             require_binary = FALSE,
+             require_ultrametric = TRUE)
+
   if (inherits(phy, "phylo")) {
 
     if (length(phy$tip.label) < 100) {
