@@ -1,4 +1,4 @@
-#' imbalance steps index
+#' Imbalance steps index
 #' @description Calculates the number of moves required to transform the focal
 #' tree into a fully imbalanced (caterpillar) tree. Higher value indicates a
 #' more balanced tree.
@@ -11,7 +11,6 @@
 #' @export
 imbalance_steps <- function(input_obj,
                             normalization = FALSE) {
-  normalization <- check_normalization_key(normalization, TRUE)
 
   if (inherits(input_obj, "phylo")) {
     input_obj <- treestats::phylo_to_l(input_obj)
@@ -27,6 +26,5 @@ imbalance_steps <- function(input_obj,
 
   steps_taken <- imbalance_steps_cpp(input_obj,
                                      normalization)
-
   return(steps_taken)
 }
