@@ -1,4 +1,4 @@
-#' Fast function using C++ to calculate the variance of all pairwise distances.
+#' Variance of all pairwise distances.
 #' @description After calculating all pairwise distances between all tips,
 #' this function takes the variance across these values.
 #' @param phy phylo object or ltable
@@ -13,12 +13,6 @@ var_pair_dist <- function(phy) {
     phy <- treestats::l_to_phylo(phy)
   }
   if (inherits(phy, "phylo")) {
-    n <- length(phy$tip.label)
-    m <- phy$Nnode
-    nm <- n + m
-    if (nm > 46340) { # sqrt(2^31 - 1) #nolint
-      stop("tree too big")
-    }
     return(calc_var_mpd_cpp(phy))
   }
   stop("input object has to be phylo or ltable")
